Adafruit CircuitPython RSA API
===============================
.. If you created a package, create one automodule per module in the package.

.. If your library file(s) are nested in a directory (e.g. /adafruit_foo/foo.py)
.. use this format as the module name: "adafruit_foo.foo"

.. automodule:: adafruit_rsa
   :members:

.. automodule:: adafruit_rsa._compat
   :members:

.. automodule:: adafruit_rsa.asn1

   .. autoclass:: PubKeyHeader
   .. autoclass:: OpenSSLPubKey
   .. autoclass:: AsnPubKey

.. automodule:: adafruit_rsa.common
   :members:

.. automodule:: adafruit_rsa.core
   :members:

.. automodule:: adafruit_rsa.key
   :members:

.. automodule:: adafruit_rsa.machine_size
   :members:

.. automodule:: adafruit_rsa.pem
   :members:

.. automodule:: adafruit_rsa.pkcs1
   :members:

.. automodule:: adafruit_rsa.prime
   :members:

.. automodule:: adafruit_rsa.randnum
   :members:

.. automodule:: adafruit_rsa.transform
   :members:
